lavalink_rs.model.search API documentation

# lavalink_rs.model.search

class SearchEngines:
def youtube(query):

The type of the None singleton.

def youtube_music(query):

The type of the None singleton.

def soundcloud(query):

The type of the None singleton.

def spotify(query):

The type of the None singleton.

def spotify_recommended(query, parameters):

The type of the None singleton.

def apple_music(query):

The type of the None singleton.

def deezer(query):

The type of the None singleton.

def deezer_isrc(query):

The type of the None singleton.

def yandex_music(query):

The type of the None singleton.

def flowery_tts(query, parameters):

The type of the None singleton.

class SpotifyRecommendedParameters:

Any of the seed fields must have a value.

Spotify documentation can be found here

target_popularity
max_time_signature
target_speechiness
max_key
max_popularity
market
min_liveness
target_liveness
seed_artists
min_tempo
max_valence
min_instrumentalness
target_acousticness
min_duration_ms
max_loudness
min_valence
limit
target_key
min_loudness
target_time_signature
min_acousticness
max_liveness
max_tempo
seed_genres
target_mode
min_key
min_mode
min_time_signature
target_danceability
max_duration_ms
max_acousticness
min_danceability
target_energy
max_danceability
target_loudness
max_energy
target_valence
min_popularity
target_instrumentalness
max_speechiness
max_mode
target_duration_ms
min_speechiness
max_instrumentalness
target_tempo
seed_tracks
min_energy
class FloweryTTSParameters:
silence

The silence parameter is in milliseconds. Range is 0 to 10000. The default is 0.

translate

TODO: Document this.

audio_format

Supported formats are: mp3, ogg_opus, ogg_vorbis, aac, wav, and flac.

speed

The speed parameter is a float between 0.5 and 10. The default is 1.0. (0.5 is half speed, 2.0 is double speed, etc.)

voice

A list of voices can be found here